from .BiossesSTS import *
from .SickrSTS import *
from .STS12STS import *
from .STS13STS import *
from .STS14STS import *
from .STS15STS import *
from .STS16STS import *
from .STS17CrosslingualSTS import *
from .STS22CrosslingualSTS import *
from .STSBenchmarkSTS import *
from .CMTEBSTS import *
from .PolishSTS import *
