from .AmazonCounterfactualClassification import *
from .AmazonPolarityClassification import *
from .AmazonReviewsClassification import *
from .AngryTweetsClassification import *
from .Banking77Classification import *
from .DalajClassification import *
from .DanishPoliticalCommentsClassification import *
from .DKHateClassification import *
from .EmotionClassification import *
from .ImdbClassification import *
from .LccSentimentClassification import *
from .MassiveIntentClassification import *
from .MassiveScenarioClassification import *
from .MTOPDomainClassification import *
from .MTOPIntentClassification import *
from .NoRecClassification import *
from .NordicLangClassification import *
from .NorwegianParliamentClassification import *
from .ScalaClassification import *
from .SweRecClassification import *
from .ToxicConversationsClassification import *
from .TweetSentimentExtractionClassification import *
from .CMTEBClassification import *
from .PolishClassification import *
