from .ArguAnaRetrieval import *
from .ClimateFEVERRetrieval import *
from .CQADupstackAndroidRetrieval import *
from .CQADupstackEnglishRetrieval import *
from .CQADupstackGamingRetrieval import *
from .CQADupstackGisRetrieval import *
from .CQADupstackMathematicaRetrieval import *
from .CQADupstackPhysicsRetrieval import *
from .CQADupstackProgrammersRetrieval import *
from .CQADupstackStatsRetrieval import *
from .CQADupstackTexRetrieval import *
from .CQADupstackUnixRetrieval import *
from .CQADupstackWebmastersRetrieval import *
from .CQADupstackWordpressRetrieval import *
from .DBPediaRetrieval import *
from .FEVERRetrieval import *
from .FiQA2018Retrieval import *
from .HotpotQARetrieval import *
from .MSMARCORetrieval import *
from .MSMARCOv2Retrieval import *
from .NFCorpusRetrieval import *
from .NQRetrieval import *
from .QuoraRetrieval import *
from .SCIDOCSRetrieval import *
from .SciFactRetrieval import *
from .Touche2020Retrieval import *
from .TRECCOVIDRetrieval import *
from .CMTEBRetrieval import *
from .ArguAnaPLRetrieval import *
from .DBPediaPLRetrieval import *
from .FiQAPLRetrieval import *
from .HotpotQAPLRetrieval import *
from .MSMARCOPLRetrieval import *
from .NFCorpusPLRetrieval import *
from .NQPLRetrieval import *
from .QuoraPLRetrieval import *
from .SCIDOCSPLRetrieval import *
from .SciFactPLRetrieval import *
from .TRECCOVIDPLRetrieval import *
